# Benchmarks index — xwschema

Per GUIDE_41_DOCS and GUIDE_54_BENCH. Evidence of benchmark runs.

| Report | Date | Description |
|--------|------|--------------|
| [BENCH_20251217_000000_000_LEGACY_FORMATS_SUMMARY.md](BENCH_20251217_000000_000_LEGACY_FORMATS_SUMMARY.md) | 2025-12-17 | Legacy format performance (JSON, XML, TOML, YAML) |

- **REF:** [REF_54_BENCH.md](../../REF_54_BENCH.md)
- **Tests:** [tests/3.advance/test_performance.py](../../../tests/3.advance/test_performance.py)
- **Example:** [examples/simple_examples/xwschema_parts_benchmark.py](../../../examples/simple_examples/xwschema_parts_benchmark.py)
